@@ -305,6 +305,8 @@ def dtw_barycenter_averaging(X, barycenter_size=None, init_barycenter=None, max_
     [DBA] epoch 1, cost: ...
     (5, 1)
     >>> dba_bar = dtw_barycenter_averaging(time_series)  # doctest: +ELLIPSIS
+    >>> X = to_time_series_dataset([[1, 2, 3, 4], [1, 2, 3], [2, 5, 6, 7, 8, 9]])
+    >>> bar = dtw_barycenter_averaging(X, barycenter_size=3)
 
     References
     ----------
@@ -473,6 +475,9 @@ def softdtw_barycenter(X, gamma=1.0, weights=None, method="L-BFGS-B", tol=1e-3,
     True
     >>> softdtw_barycenter(time_series, max_iter=5).shape
     (4, 1)
+    >>> time_series = [[1, 2, 3, 4], [1, 2, 3, 4, 5]]
+    >>> softdtw_barycenter(time_series, max_iter=5).shape
+    (5, 1)
     """
     X_ = to_time_series_dataset(X)
     weights = _set_weights(weights, X_.shape[0])
@@ -486,10 +491,11 @@ def softdtw_barycenter(X, gamma=1.0, weights=None, method="L-BFGS-B", tol=1e-3,
         barycenter = init
 
     if max_iter > 0:
+        X_ = numpy.array([to_time_series(d, remove_nans=True) for d in X_])
         f = lambda Z: _softdtw_func(Z, X_, weights, barycenter, gamma)
         # The function works with vectors so we need to vectorize barycenter.
         res = minimize(f, barycenter.ravel(), method=method, jac=True, tol=tol,
                        options=dict(maxiter=max_iter, disp=False))
         return res.x.reshape(barycenter.shape)
     else:
-        return barycenter
\ No newline at end of file
+        return barycenter
